===================
Layered Config Tree
===================

Layered Config Tree is a configuration structure that supports cascading layers.

**Supported Python versions: 3.10, 3.11, 3.12, 3.13**

You can install ``layered_config_tree`` from PyPI with pip:

  ``> pip install layered_config_tree``

or build it from from source:

  ``> git clone https://github.com/ihmeuw/layered_config_tree.git``

  ``> cd layered_config_tree``

  ``> conda create -n ENVIRONMENT_NAME python=3.13``

  ``> pip install .``

This will make the ``layered_config_tree`` library available to python.
